==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkOpenGLRenderWindow.java <==
// java wrapper for vtkOpenGLRenderWindow object
//

package vtk;
import vtk.*;

public class vtkOpenGLRenderWindow extends vtkRenderWindow
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetRenderingBackend_2();
  public String GetRenderingBackend()
    { return GetRenderingBackend_2(); }

  private native void SetGlobalMaximumNumberOfMultiSamples_3(int id0);
  public void SetGlobalMaximumNumberOfMultiSamples(int id0)
    { SetGlobalMaximumNumberOfMultiSamples_3(id0); }

  private native int GetGlobalMaximumNumberOfMultiSamples_4();
  public int GetGlobalMaximumNumberOfMultiSamples()
    { return GetGlobalMaximumNumberOfMultiSamples_4(); }

  private native void StereoUpdate_5();
  public void StereoUpdate()
    { StereoUpdate_5(); }

  private native int GetPixelData_6(int id0,int id1,int id2,int id3,int id4,vtkUnsignedCharArray id5);
  public int GetPixelData(int id0,int id1,int id2,int id3,int id4,vtkUnsignedCharArray id5)
    { return GetPixelData_6(id0,id1,id2,id3,id4,id5); }

  private native int SetPixelData_7(int id0,int id1,int id2,int id3,vtkUnsignedCharArray id4,int id5);
  public int SetPixelData(int id0,int id1,int id2,int id3,vtkUnsignedCharArray id4,int id5)
    { return SetPixelData_7(id0,id1,id2,id3,id4,id5); }

  private native int GetRGBAPixelData_8(int id0,int id1,int id2,int id3,int id4,vtkFloatArray id5);
  public int GetRGBAPixelData(int id0,int id1,int id2,int id3,int id4,vtkFloatArray id5)
    { return GetRGBAPixelData_8(id0,id1,id2,id3,id4,id5); }

  private native int SetRGBAPixelData_9(int id0,int id1,int id2,int id3,vtkFloatArray id4,int id5,int id6);
  public int SetRGBAPixelData(int id0,int id1,int id2,int id3,vtkFloatArray id4,int id5,int id6)
    { return SetRGBAPixelData_9(id0,id1,id2,id3,id4,id5,id6); }

  private native int GetRGBACharPixelData_10(int id0,int id1,int id2,int id3,int id4,vtkUnsignedCharArray id5);
  public int GetRGBACharPixelData(int id0,int id1,int id2,int id3,int id4,vtkUnsignedCharArray id5)
    { return GetRGBACharPixelData_10(id0,id1,id2,id3,id4,id5); }

  private native int SetRGBACharPixelData_11(int id0,int id1,int id2,int id3,vtkUnsignedCharArray id4,int id5,int id6);
  public int SetRGBACharPixelData(int id0,int id1,int id2,int id3,vtkUnsignedCharArray id4,int id5,int id6)
    { return SetRGBACharPixelData_11(id0,id1,id2,id3,id4,id5,id6); }

  private native int GetZbufferData_12(int id0,int id1,int id2,int id3,vtkFloatArray id4);
  public int GetZbufferData(int id0,int id1,int id2,int id3,vtkFloatArray id4)
    { return GetZbufferData_12(id0,id1,id2,id3,id4); }

  private native int SetZbufferData_13(int id0,int id1,int id2,int id3,vtkFloatArray id4);
  public int SetZbufferData(int id0,int id1,int id2,int id3,vtkFloatArray id4)
    { return SetZbufferData_13(id0,id1,id2,id3,id4); }

  private native int GetDepthBufferSize_14();
  public int GetDepthBufferSize()
    { return GetDepthBufferSize_14(); }

  private native void SetSize_15(int id0[]);
  public void SetSize(int id0[])
    { SetSize_15(id0); }

  private native void SetSize_16(int id0,int id1);
  public void SetSize(int id0,int id1)
    { SetSize_16(id0,id1); }

  private native void OpenGLInit_17();
  public void OpenGLInit()
    { OpenGLInit_17(); }

  private native void OpenGLInitState_18();
  public void OpenGLInitState()
    { OpenGLInitState_18(); }

  private native void OpenGLInitContext_19();
  public void OpenGLInitContext()
    { OpenGLInitContext_19(); }

  private native boolean GetContextSupportsOpenGL32_20();
  public boolean GetContextSupportsOpenGL32()
    { return GetContextSupportsOpenGL32_20(); }

  private native void SetContextSupportsOpenGL32_21(boolean id0);
  public void SetContextSupportsOpenGL32(boolean id0)
    { SetContextSupportsOpenGL32_21(id0); }

  private native int GetBackLeftBuffer_22();
  public int GetBackLeftBuffer()
    { return GetBackLeftBuffer_22(); }

  private native int GetBackRightBuffer_23();
  public int GetBackRightBuffer()
    { return GetBackRightBuffer_23(); }

  private native int GetFrontLeftBuffer_24();
  public int GetFrontLeftBuffer()
    { return GetFrontLeftBuffer_24(); }

  private native int GetFrontRightBuffer_25();
  public int GetFrontRightBuffer()
    { return GetFrontRightBuffer_25(); }

  private native int GetBackBuffer_26();
  public int GetBackBuffer()
    { return GetBackBuffer_26(); }

  private native int GetFrontBuffer_27();
  public int GetFrontBuffer()
    { return GetFrontBuffer_27(); }

  private native int GetContextCreationTime_28();
  public int GetContextCreationTime()
    { return GetContextCreationTime_28(); }

  private native int GetFrameBufferObject_29();
  public int GetFrameBufferObject()
    { return GetFrameBufferObject_29(); }

  private native void WaitForCompletion_30();
  public void WaitForCompletion()
    { WaitForCompletion_30(); }

  private native double GetMaximumHardwareLineWidth_31();
  public double GetMaximumHardwareLineWidth()
    { return GetMaximumHardwareLineWidth_31(); }

  private native boolean IsPointSpriteBugPresent_32();
  public boolean IsPointSpriteBugPresent()
    { return IsPointSpriteBugPresent_32(); }

  private native int GetDefaultTextureInternalFormat_33(int id0,int id1,boolean id2,boolean id3);
  public int GetDefaultTextureInternalFormat(int id0,int id1,boolean id2,boolean id3)
    { return GetDefaultTextureInternalFormat_33(id0,id1,id2,id3); }

  private native String GetOpenGLSupportMessage_34();
  public String GetOpenGLSupportMessage()
    { return GetOpenGLSupportMessage_34(); }

  private native int SetUseOffScreenBuffers_35(boolean id0);
  public int SetUseOffScreenBuffers(boolean id0)
    { return SetUseOffScreenBuffers_35(id0); }

  private native boolean GetUseOffScreenBuffers_36();
  public boolean GetUseOffScreenBuffers()
    { return GetUseOffScreenBuffers_36(); }

  private native int SupportsOpenGL_37();
  public int SupportsOpenGL()
    { return SupportsOpenGL_37(); }

  private native void Initialize_38();
  public void Initialize()
    { Initialize_38(); }

  private native void PushContext_39();
  public void PushContext()
    { PushContext_39(); }

  private native void PopContext_40();
  public void PopContext()
    { PopContext_40(); }

  public vtkOpenGLRenderWindow() { super(); }

  public vtkOpenGLRenderWindow(long id) { super(id); }

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkOpenGLRenderWindow.java <==
// java wrapper for vtkOpenGLRenderWindow object
//

package vtk;
import vtk.*;

public class vtkOpenGLRenderWindow extends vtkRenderWindow
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetRenderingBackend_2();
  public String GetRenderingBackend()
    { return GetRenderingBackend_2(); }

  private native void SetGlobalMaximumNumberOfMultiSamples_3(int id0);
  public void SetGlobalMaximumNumberOfMultiSamples(int id0)
    { SetGlobalMaximumNumberOfMultiSamples_3(id0); }

  private native int GetGlobalMaximumNumberOfMultiSamples_4();
  public int GetGlobalMaximumNumberOfMultiSamples()
    { return GetGlobalMaximumNumberOfMultiSamples_4(); }

  private native void StereoUpdate_5();
  public void StereoUpdate()
    { StereoUpdate_5(); }

  private native int GetPixelData_6(int id0,int id1,int id2,int id3,int id4,vtkUnsignedCharArray id5);
  public int GetPixelData(int id0,int id1,int id2,int id3,int id4,vtkUnsignedCharArray id5)
    { return GetPixelData_6(id0,id1,id2,id3,id4,id5); }

  private native int SetPixelData_7(int id0,int id1,int id2,int id3,vtkUnsignedCharArray id4,int id5);
  public int SetPixelData(int id0,int id1,int id2,int id3,vtkUnsignedCharArray id4,int id5)
    { return SetPixelData_7(id0,id1,id2,id3,id4,id5); }

  private native int GetRGBAPixelData_8(int id0,int id1,int id2,int id3,int id4,vtkFloatArray id5);
  public int GetRGBAPixelData(int id0,int id1,int id2,int id3,int id4,vtkFloatArray id5)
    { return GetRGBAPixelData_8(id0,id1,id2,id3,id4,id5); }

  private native int SetRGBAPixelData_9(int id0,int id1,int id2,int id3,vtkFloatArray id4,int id5,int id6);
  public int SetRGBAPixelData(int id0,int id1,int id2,int id3,vtkFloatArray id4,int id5,int id6)
    { return SetRGBAPixelData_9(id0,id1,id2,id3,id4,id5,id6); }

  private native int GetRGBACharPixelData_10(int id0,int id1,int id2,int id3,int id4,vtkUnsignedCharArray id5);
  public int GetRGBACharPixelData(int id0,int id1,int id2,int id3,int id4,vtkUnsignedCharArray id5)
    { return GetRGBACharPixelData_10(id0,id1,id2,id3,id4,id5); }

  private native int SetRGBACharPixelData_11(int id0,int id1,int id2,int id3,vtkUnsignedCharArray id4,int id5,int id6);
  public int SetRGBACharPixelData(int id0,int id1,int id2,int id3,vtkUnsignedCharArray id4,int id5,int id6)
    { return SetRGBACharPixelData_11(id0,id1,id2,id3,id4,id5,id6); }

  private native int GetZbufferData_12(int id0,int id1,int id2,int id3,vtkFloatArray id4);
  public int GetZbufferData(int id0,int id1,int id2,int id3,vtkFloatArray id4)
    { return GetZbufferData_12(id0,id1,id2,id3,id4); }

  private native int SetZbufferData_13(int id0,int id1,int id2,int id3,vtkFloatArray id4);
  public int SetZbufferData(int id0,int id1,int id2,int id3,vtkFloatArray id4)
    { return SetZbufferData_13(id0,id1,id2,id3,id4); }

  private native int GetDepthBufferSize_14();
  public int GetDepthBufferSize()
    { return GetDepthBufferSize_14(); }

  private native void SetSize_15(int id0[]);
  public void SetSize(int id0[])
    { SetSize_15(id0); }

  private native void SetSize_16(int id0,int id1);
  public void SetSize(int id0,int id1)
    { SetSize_16(id0,id1); }

  private native void OpenGLInit_17();
  public void OpenGLInit()
    { OpenGLInit_17(); }

  private native void OpenGLInitState_18();
  public void OpenGLInitState()
    { OpenGLInitState_18(); }

  private native void OpenGLInitContext_19();
  public void OpenGLInitContext()
    { OpenGLInitContext_19(); }

  private native boolean GetContextSupportsOpenGL32_20();
  public boolean GetContextSupportsOpenGL32()
    { return GetContextSupportsOpenGL32_20(); }

  private native void SetContextSupportsOpenGL32_21(boolean id0);
  public void SetContextSupportsOpenGL32(boolean id0)
    { SetContextSupportsOpenGL32_21(id0); }

  private native int GetBackLeftBuffer_22();
  public int GetBackLeftBuffer()
    { return GetBackLeftBuffer_22(); }

  private native int GetBackRightBuffer_23();
  public int GetBackRightBuffer()
    { return GetBackRightBuffer_23(); }

  private native int GetFrontLeftBuffer_24();
  public int GetFrontLeftBuffer()
    { return GetFrontLeftBuffer_24(); }

  private native int GetFrontRightBuffer_25();
  public int GetFrontRightBuffer()
    { return GetFrontRightBuffer_25(); }

  private native int GetBackBuffer_26();
  public int GetBackBuffer()
    { return GetBackBuffer_26(); }

  private native int GetFrontBuffer_27();
  public int GetFrontBuffer()
    { return GetFrontBuffer_27(); }

  private native int GetContextCreationTime_28();
  public int GetContextCreationTime()
    { return GetContextCreationTime_28(); }

  private native int GetFrameBufferObject_29();
  public int GetFrameBufferObject()
    { return GetFrameBufferObject_29(); }

  private native void WaitForCompletion_30();
  public void WaitForCompletion()
    { WaitForCompletion_30(); }

  private native double GetMaximumHardwareLineWidth_31();
  public double GetMaximumHardwareLineWidth()
    { return GetMaximumHardwareLineWidth_31(); }

  private native boolean IsPointSpriteBugPresent_32();
  public boolean IsPointSpriteBugPresent()
    { return IsPointSpriteBugPresent_32(); }

  private native int GetDefaultTextureInternalFormat_33(int id0,int id1,boolean id2,boolean id3);
  public int GetDefaultTextureInternalFormat(int id0,int id1,boolean id2,boolean id3)
    { return GetDefaultTextureInternalFormat_33(id0,id1,id2,id3); }

  private native String GetOpenGLSupportMessage_34();
  public String GetOpenGLSupportMessage()
    { return GetOpenGLSupportMessage_34(); }

  private native int SetUseOffScreenBuffers_35(boolean id0);
  public int SetUseOffScreenBuffers(boolean id0)
    { return SetUseOffScreenBuffers_35(id0); }

  private native boolean GetUseOffScreenBuffers_36();
  public boolean GetUseOffScreenBuffers()
    { return GetUseOffScreenBuffers_36(); }

  private native int SupportsOpenGL_37();
  public int SupportsOpenGL()
    { return SupportsOpenGL_37(); }

  private native String ReportCapabilities_38();
  public String ReportCapabilities()
    { return ReportCapabilities_38(); }

  private native void Initialize_39();
  public void Initialize()
    { Initialize_39(); }

  private native void PushContext_40();
  public void PushContext()
    { PushContext_40(); }

  private native void PopContext_41();
  public void PopContext()
    { PopContext_41(); }

  private native boolean InitializeFromCurrentContext_42();
  public boolean InitializeFromCurrentContext()
    { return InitializeFromCurrentContext_42(); }

  private native int GetDefaultFrameBufferId_43();
  public int GetDefaultFrameBufferId()
    { return GetDefaultFrameBufferId_43(); }

  public vtkOpenGLRenderWindow() { super(); }

  public vtkOpenGLRenderWindow(long id) { super(id); }

}
